Enum ReadDataBlockError

pub enum ReadDataBlockError {
    IoError,
    UnsupportedLocation,
    DifferentChecksum,
    BadByteShuffleItemSize,
    FileInUse,
    BadTextEncoding,
    UntrustedHost(Host),
    Unauthorized(Url),
    UnsupportedScheme(String),
    MissingHost,
}
A failure to read bytes from a DataBlock

Variants



IoError

Something went wrong while interacting with the underlying file or stream



UnsupportedLocation

The data block location is not supported for the current file

For example, trying to access a remote data block in a monolithic file, or trying to access an attached data block in a distributed file.



DifferentChecksum

The checksum failed verification



BadByteShuffleItemSize



FileInUse

Failed to read an attached data block because the file is in use by another data block

I’m pretty sure this is impossible to get with safe rust since Context doesn’t impl Send + Sync, and the file handle is released by the time the public API call finishes, but it’s here just in case I’m wrong.



BadTextEncoding

Failed to read an inline/embedded data block



UntrustedHost(Host)

The host is not in the context’s

Ask the user if they trust the provided host, and if yes, add it to the context with Context::trust_host, and try to read the block again

This should not be done automatically, as a malicious server could permanently hang the reader. Always ask before adding a trusted host.


Unauthorized(Url)

Failed to authenticate with the remote host

Some servers may enforce a cooldown period between attempts, so it's best to be proactive in asking for credentials before connecting. Consider asking for credentials at the same time as when you ask the user to trust the host.


UnsupportedScheme(String)

Current supported schemes: ftp, http, https, file



MissingHost

The URL for this data block is missing a remote host