pub struct ParseNodeError {
pub tag: &'static str,
pub kind: ParseNodeErrorKind,
}Expand description
A failure to parse a Core Element from the XML document making up an XISF header
Fields
tag: &'static strThe XML tag name of the element that could not be parsed
E.g. if an <Image ...> element could not be parsed, tag will be “Image”
kind: ParseNodeErrorKindWhat went wrong while trying to parse the element