pub struct ReadFileError;Expand description
A failure to read an XISF file
Since data from XISF files are read lazily, a lack of ReadFileError does not guarantee that
all data blocks can be read, or all FITS keys/XISF properties can be parsed, for example.