Enum Resolution

pub enum Resolution {
    Inch {
        horizontal: f32,
        vertical: f32,
    },
    Cm {
        horizontal: f32,
        vertical: f32,
    },
}
The pixel density of the image, in pixels per inch or pixels per centimeter

Although it would be unusual for horizontal and vertical pixel density to differ, as this would result in a stretched image for most media, they are specified separately.

Variants



Inch

Pixel density is measured in pixels per inch

Fields

horizontal: f32

Horizontal pixel density, in pixels per inch

Recall that XISF images are stored in row-major order, so this should be applied to dimension 1 (zero-indexed)

vertical: f32

Vertical pixel density, in pixels per inch

Recall that XISF images are stored in row-major order, so this should be applied to dimension 0 (zero-indexed)



Cm

Pixel density is measured in pixels per centimeter

Fields

horizontal: f32

Horizontal pixel density, in pixels per centimeter

Recall that XISF images are stored in row-major order, so this should be applied to dimension 1 (zero-indexed)

vertical: f32

Vertical pixel density, in pixels per centimeter

Recall that XISF images are stored in row-major order, so this should be applied to dimension 0 (zero-indexed)