pub struct Normal;Expand description
The image is laid out with each pixel having all of its values for each channel stored sequentially
For example, consider a 2D RGB image.
Since XISF images are stored in row-major order, this means the pixels are laid out in the order
(0,0), (0,1), (1,0), (1,1). For a normal-layout image, the samples would in the following order:
(0,0,R), (0,0,G), (0,0,B), (0,1,R), (0,1,G), (0,1,B), (1,0,R), (1,0,G), (1,0,B), (1,1,R), (1,1,G), (1,1,B).
See also PixelStorage; contrast with Planar.
See the spec
for more information.