Struct DisplayFunction

pub struct DisplayFunction { /* private fields */ }
A multi-channel screen transfer function

Implementations

Source

impl DisplayFunction

pub fn name(&self) -> Option<&str>

A common name used to distinguish this display function from others or describe its behavior. May contain any valid Unicode.

pub fn r(&self) -> &STF

Screen transfer functions for the red channel of an RGB image

pub fn k(&self) -> &STF

Screen transfer function for the single channel of a grayscale image – just an alias for Self::r()

pub fn g(&self) -> &STF

Screen transfer functions for the red channel of an RGB image

pub fn b(&self) -> &STF

Screen transfer functions for the red channel of an RGB image

pub fn l(&self) -> &STF

Screen transfer function for grayscale/luminance previews of an RGB image

Do not use this for grayscale images! This STF is only meant to be used for grayscale previews of color images. For grayscale images, Self::k() should be used instead.