pub enum ReferenceError {
MissingRef,
InvalidUid,
NotFound,
Recursive,
Ambiguous,
}Expand description
A failure to either parse or resolve a <Reference> XML element
Enum variants are listed in order of precedence, e.g. if the parser encounters the node
<Reference uid="invalid uid" ref="invalid uid" /> (a recursive reference and an invalid uid)
attempting to resolve the reference will return InvalidUid instead of Recursive
Variants
MissingRef
The ref attribute is missing, so there isn’t anything to search for
InvalidUid
The ref attribute contains an invalid uid
Valid uids satisfy the regex [_a-zA-Z][_a-zA-Z0-9]*
NotFound
No elements found with the requested uid
Recursive
Reference to a reference
Ambiguous
More than one element was found with the requested uid