pub enum Resolution {
Inch {
horizontal: f32,
vertical: f32,
},
Cm {
horizontal: f32,
vertical: f32,
},
}Expand description
The pixel density of the image, in pixels per inch or pixels per centimeter
Although it would be unusual for horizontal and vertical pixel density to differ, as this would result in a stretched image for most media, they are specified separately.
Variants
Inch
Pixel density is measured in pixels per inch
Fields
Cm
Pixel density is measured in pixels per centimeter